@@ -49,6 +49,14 @@ extern void case_upperb (char *, size_t) ;
 #define case_equalb(a, n, b) (!strncasecmp(a, (b), n))
 #define case_starts(s, t) case_startb(s, strlen(s), t)
 extern int case_startb (char const *, size_t, char const *) gccattr_pure ;
-extern size_t case_str (char const *, char const *) gccattr_pure ;
+
+extern int str_cmp (void const *, void const *) gccattr_pure ;
+extern int str_bcmp (void const *, void const *) gccattr_pure ;
+extern int str_casecmp (void const *, void const *) gccattr_pure ;
+extern int str_bcasecmp (void const *, void const *) gccattr_pure ;
+extern int stringkey_cmp (void const *, void const *) gccattr_pure ;
+extern int stringkey_bcmp (void const *, void const *) gccattr_pure ;
+extern int stringkey_casecmp (void const *, void const *) gccattr_pure ;
+extern int stringkey_bcasecmp (void const *, void const *) gccattr_pure ;
 
 #endif
