@@ -31,7 +31,7 @@ extern int fd_sync (int) ;
 extern off_t fd_cat (int, int) ;
 extern off_t fd_catn (int, int, off_t) ;
 extern int fd_ensure_open (int, int) ;
-#define fd_sanitize() (fd_ensure_open(0, 0) && fd_ensure_open(1, 1) && fd_ensure_open(2, 1))
+extern int fd_sanitize (void) ;
 extern void fd_shutdown (int, int) ;
 
 extern int fd_lock (int, int, int) ;
@@ -82,6 +82,7 @@ extern int sadirname (stralloc *, char const *, size_t) ;
 extern int sagetcwd (stralloc *) ;
 extern int sareadlink (stralloc *, char const *) ;
 extern int sagethostname (stralloc *) ;
+extern int sagetexecname (stralloc *) ;
 
 #define slurp(sa, fd) slurpn((fd), (sa), 0)
 #define openslurpclose(sa, fn) openslurpnclose((fn), (sa), 0)
