@@ -4,11 +4,12 @@
 #define SKALIBS_STRERR_H
 
 #include <skalibs/gccattributes.h>
+#include <skalibs/prog.h>
 
 extern void strerr_warnv (char const *const *, unsigned int) ;
 extern void strerr_warnvsys (char const *const *, unsigned int) ;
 extern void strerr_diev (int, char const *const *, unsigned int) gccattr_noreturn ;
-extern void strerr_dievsys(int, char const *const *, unsigned int) gccattr_noreturn ;
+extern void strerr_dievsys (int, char const *const *, unsigned int) gccattr_noreturn ;
 
 #define strerr_array(...) ((char const *const[]){__VA_ARGS__})
 #define strerr_warnn(n, ...) strerr_warnv(strerr_array(__VA_ARGS__), (n))
@@ -21,8 +22,6 @@ extern void strerr_dievsys(int, char const *const *, unsigned int) gccattr_noret
 #define strerr_die(e, ...) strerr_dien(e, sizeof(strerr_array(__VA_ARGS__))/sizeof(char const *), __VA_ARGS__)
 #define strerr_diesys(e, ...) strerr_diensys(e, sizeof(strerr_array(__VA_ARGS__))/sizeof(char const *), __VA_ARGS__)
 
-extern char const *PROG ;
-
 #define strerr_warnwn(n, ...) strerr_warnn((n)+2, PROG, ": warning: ", __VA_ARGS__)
 #define strerr_warnwnsys(n, ...) strerr_warnnsys((n)+2, PROG, ": warning: ", __VA_ARGS__)
 #define strerr_warnfn(n, ...) strerr_warnn((n)+2, PROG, ": fatal: ", __VA_ARGS__)
@@ -61,13 +60,17 @@ extern char const *PROG ;
 
 #define strerr_warnin(n, ...) strerr_warnn((n)+2, PROG, ": info: ", __VA_ARGS__)
 #define strerr_warninsys(n, ...) strerr_warnnsys((n)+2, PROG, ": info: ", __VA_ARGS__)
-#define strerr_warntn(n, ...) strerr_warnn((n)+2, PROG, ": tracing: ", __VA_ARGS__)
-#define strerr_warntnsys(n, ...) strerr_warnnsys((n)+2, PROG, ": tracing: ", __VA_ARGS__)
+#define strerr_warntn(n, ...) strerr_warnn((n)+4, PROG, ": tracing: in ", __func__, ": ", __VA_ARGS__)
+#define strerr_warntnsys(n, ...) strerr_warnnsys((n)+4, PROG, ": tracing: in ", __func__, ": ", __VA_ARGS__)
+#define strerr_warndn(n, ...) strerr_warnn((n)+4, PROG, ": debug: in ", __func__, ": ", __VA_ARGS__)
+#define strerr_warndnsys(n, ...) strerr_warnnsys((n)+4, PROG, ": debug: in ", __func__, ": ", __VA_ARGS__)
 
 #define strerr_warni(...) strerr_warn(PROG, ": info: ", __VA_ARGS__)
 #define strerr_warnisys(...) strerr_warnsys(PROG, ": info: ", __VA_ARGS__)
-#define strerr_warnt(...) strerr_warn(PROG, ": tracing: ", __VA_ARGS__)
-#define strerr_warntsys(...) strerr_warnsys(PROG, ": tracing: ", __VA_ARGS__)
+#define strerr_warnt(...) strerr_warn(PROG, ": tracing: in ", __func__, ": ", __VA_ARGS__)
+#define strerr_warntsys(...) strerr_warnsys(PROG, ": tracing: in ", __func__, ": ", __VA_ARGS__)
+#define strerr_warnd(...) strerr_warn(PROG, ": debug: in ", __func__, ": ", __VA_ARGS__)
+#define strerr_warndsys(...) strerr_warnsys(PROG, ": debug: in ", __func__, ": ", __VA_ARGS__)
 
 #define strerr_dieusage(e, u) strerr_dien(e, 3, PROG, ": usage: ", u)
 #define strerr_dienotset(e, x) strerr_diefn(e, 2, (x), " not set")
@@ -297,4 +300,26 @@ extern char const *PROG ;
 #define strerr_warnt9sys(x1, x2, x3, x4, x5, x6, x7, x8, x9) strerr_warntnsys(9, x1, x2, x3, x4, x5, x6, x7, x8, x9)
 #define strerr_warnt10sys(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10) strerr_warntnsys(10, x1, x2, x3, x4, x5, x6, x7, x8, x9, x10)
 
+#define strerr_warnd1x(x1) strerr_warndn(1, x1)
+#define strerr_warnd2x(x1, x2) strerr_warndn(2, x1, x2)
+#define strerr_warnd3x(x1, x2, x3) strerr_warndn(3, x1, x2, x3)
+#define strerr_warnd4x(x1, x2, x3, x4) strerr_warndn(4, x1, x2, x3, x4)
+#define strerr_warnd5x(x1, x2, x3, x4, x5) strerr_warndn(5, x1, x2, x3, x4, x5)
+#define strerr_warnd6x(x1, x2, x3, x4, x5, x6) strerr_warndn(6, x1, x2, x3, x4, x5, x6)
+#define strerr_warnd7x(x1, x2, x3, x4, x5, x6, x7) strerr_warndn(7, x1, x2, x3, x4, x5, x6, x7)
+#define strerr_warnd8x(x1, x2, x3, x4, x5, x6, x7, x8) strerr_warndn(8, x1, x2, x3, x4, x5, x6, x7, x8)
+#define strerr_warnd9x(x1, x2, x3, x4, x5, x6, x7, x8, x9) strerr_warndn(9, x1, x2, x3, x4, x5, x6, x7, x8, x9)
+#define strerr_warnd10x(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10) strerr_warndn(10, x1, x2, x3, x4, x5, x6, x7, x8, x9, x10)
+
+#define strerr_warnd1sys(x1) strerr_warndnsys(1, x1)
+#define strerr_warnd2sys(x1, x2) strerr_warndnsys(2, x1, x2)
+#define strerr_warnd3sys(x1, x2, x3) strerr_warndnsys(3, x1, x2, x3)
+#define strerr_warnd4sys(x1, x2, x3, x4) strerr_warndnsys(4, x1, x2, x3, x4)
+#define strerr_warnd5sys(x1, x2, x3, x4, x5) strerr_warndnsys(5, x1, x2, x3, x4, x5)
+#define strerr_warnd6sys(x1, x2, x3, x4, x5, x6) strerr_warndnsys(6, x1, x2, x3, x4, x5, x6)
+#define strerr_warnd7sys(x1, x2, x3, x4, x5, x6, x7) strerr_warndnsys(7, x1, x2, x3, x4, x5, x6, x7)
+#define strerr_warnd8sys(x1, x2, x3, x4, x5, x6, x7, x8) strerr_warndnsys(8, x1, x2, x3, x4, x5, x6, x7, x8)
+#define strerr_warnd9sys(x1, x2, x3, x4, x5, x6, x7, x8, x9) strerr_warndnsys(9, x1, x2, x3, x4, x5, x6, x7, x8, x9)
+#define strerr_warnd10sys(x1, x2, x3, x4, x5, x6, x7, x8, x9, x10) strerr_warndnsys(10, x1, x2, x3, x4, x5, x6, x7, x8, x9, x10)
+
 #endif
