@@ -2,12 +2,13 @@
 
 #include <unistd.h>
 #include <errno.h>
+
 #include <skalibs/djbunix.h>
 
 int fd_move (int to, int from)
 {
   int r ;
-  if (to == from) return 0 ;
+  if (to == from) return uncoe(to) ;
   do
     r = dup2(from, to) ;
   while ((r == -1) && (errno == EINTR)) ;
