@@ -2,8 +2,7 @@
 
 #include <skalibs/nonposix.h>
 #include <sys/socket.h>
-#include <skalibs/djbunix.h>
-#include <skalibs/webipc.h>
+#include <skalibs/socket.h>
 
 int ipc_pair_internal (int *sv, unsigned int flags)
 {
