@@ -1,7 +1,7 @@
 /* ISC license. */
 
 #include <skalibs/nonposix.h>
-#include <fcntl.h>
+#include <skalibs/fcntl.h>
 #include <skalibs/djbunix.h>
 
 int openb_read (char const *fn)
