@@ -1,5 +1,12 @@
 /* ISC license. */
 
+#undef _POSIX_C_SOURCE
+#undef _XOPEN_SOURCE
+
+#ifndef _DARWIN_C_SOURCE
+#define _DARWIN_C_SOURCE
+#endif
+
 #include <sys/stat.h>
 #include <time.h>
 
